// AbbreviationsDlg.h
// (c) 2004-2005 exeal

#ifndef _ABBREVIATIONS_DLG_H_
#define _ABBREVIATIONS_DLG_H_
#include "../Manah/Dialog.h"


namespace Alpha {

///	[Zk̊Ǘ] _CAO
class CAbbreviationsDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_ABBREVIATIONS> {
	// \bh
private:
	void	Update();

	// bZ[Wnh
protected:
	bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
	bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
	void	OnOK();													// IDOK

	// NX
private:
	class CNewAbbreviationDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_NEWABBREV> {
		// f[^o
	public:
		wchar_t	m_wszAbbreviation[1000];
		wchar_t	m_wszExpanded[1000];
		HWND	m_hAbbreviationsListCtrl;

		// bZ[Wnh
	protected:
		bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);
		bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);
		void	OnOK();
	};
};

} // namespace Alpha

#endif /* _ABBREVIATIONS_DLG_H_ */

/* [EOF] */